Example
===================

A fully functioning example showcasing multithreaded communication and a responsive graphical user-interface with real-time plotting and logging of live Arduino data can be found here:

https://github.com/Dennis-van-Gils/DvG_Arduino_PyQt_multithread_demo

TODO: Add other examples that only need a CLI and not a GUI.